import { Client } from '../../Client';
import { StaysBooking } from '../StaysTypes';
import { Resource } from '../../Resource';
import { DuffelResponse, PaginationMeta } from '../../types';
export interface StaysBookingPayload {
    quote_id: string;
    loyalty_programme_account_number?: string;
    guests: Array<{
        given_name: string;
        family_name: string;
    }>;
    email: string;
    phone_number: string;
    accommodation_special_requests?: string;
    payment?: {
        card_id: string;
    } | {
        three_d_secure_session_id: string;
    };
    metadata?: StaysBooking['metadata'];
}
export declare class Bookings extends Resource {
    /**
     * Endpoint path
     */
    path: string;
    constructor(client: Client);
    /**
     * Create a booking
     * @param {object} payload - The booking payload, including quote id and guest information
     */
    create: (payload: StaysBookingPayload) => Promise<DuffelResponse<StaysBooking>>;
    /**
     * Get a booking
     * @param {string} bookingId - The ID of the booking
     */
    get: (bookingId: string) => Promise<DuffelResponse<StaysBooking>>;
    /**
     * List bookings
     * @param {Object} [options] - Pagination options (optional: limit, after, before)
     * @link https://duffel.com/docs/api/bookings/list-bookings
     */
    list: (options?: PaginationMeta) => Promise<DuffelResponse<StaysBooking[]>>;
    /**
     * Retrieves a generator of all bookings. The results may be returned in any order.
     * @link https://duffel.com/docs/api/bookings/list-bookings
     */
    listWithGenerator: () => AsyncGenerator<DuffelResponse<StaysBooking>, void, unknown>;
    /**
     * Cancel a booking
     * @param {string} bookingId - The ID of the booking
     */
    cancel: (bookingId: string) => Promise<DuffelResponse<StaysBooking>>;
}
